@@ -2,9 +2,12 @@ use std::any::TypeId;
 use std::iter::Iterator;
 use std::ptr::NonNull;
 
+use xjbutil::fat_ptr::FatPointer;
+use xjbutil::void::Void;
+
 use crate::data::tyck::{TyckInfo, TyckInfoPool};
-use crate::util::mem::FatPointer;
-use crate::util::void::Void;
+
+pub type ChildrenType = Option<Box<dyn Iterator<Item=FatPointer> + 'static>>;
 
 pub trait StaticBase<T: 'static> {
     fn type_id() -> TypeId {
@@ -28,9 +31,7 @@ pub trait StaticBase<T: 'static> {
     }
 
     // TODO: should we mark this as unsafe?
-    #[inline] fn children(_vself: *const T) 
-        -> Option<Box<dyn Iterator<Item=FatPointer> + 'static>> 
-    {
+    #[inline] fn children(_vself: *const T) -> ChildrenType {
         None
     }
 }
