@@ -1,17 +1,17 @@
 use crate::syntax::decl::ConcreteDecl;
 use crate::syntax::expr::ConcreteExpr;
 
-use crate::util::location::SourceLocation;
+use crate::util::location::SourceLoc;
 
 pub enum ConcreteStmt {
     CompoundStmt(ConcreteCompoundStmt),
-    ExprStmt(ConcreteExpr, SourceLocation),
-    DeclStmt(ConcreteDecl, SourceLocation)
+    ExprStmt(ConcreteExpr, SourceLoc),
+    DeclStmt(ConcreteDecl, SourceLoc)
 }
 
 pub struct ConcreteCompoundStmt {
     pub stmts: Vec<ConcreteStmt>,
 
-    pub left_brace_loc: SourceLocation,
-    pub right_brace_loc: SourceLocation
+    pub left_brace_loc: SourceLoc,
+    pub right_brace_loc: SourceLoc
 }
