@@ -2,7 +2,7 @@
 
 use std::ptr::NonNull;
 
-use crate::data::custom_vt::ContainerCtor;
+use crate::data::container::ContainerCtor;
 use crate::data::tyck::TyckInfo;
 
 /// An VM instruction
@@ -106,7 +106,9 @@ pub enum Insc {
 
     /// `EQ-VALUE [VALUE@SRC1] [VALUE@SRC2] [DEST]`
     ///
-    /// Assume that `SRC1` and `SRC2` are **values of same type**, check their equality.
+    /// Assume that `SRC1` and `SRC2` are **values of same type**, check their equality. This
+    /// instruction should not be used for float comparison. For comparing float values, use
+    /// `EQ-FLOAT`.
     EqValue(usize, usize, usize),
 
     /// `EQ-REF [REF@SRC1] [REF@SRC2] [DEST]`
@@ -397,6 +399,9 @@ pub enum Insc {
     CastAnyFloat(usize, usize),
     CastAnyChar(usize, usize),
 
+    CastIntBool(usize, usize),
+    CastAnyBool(usize, usize),
+
     /// `IS-NULL [SRC] [DEST]`
     ///
     /// Check if data stored in `SRC` is `null`, and save the boolean result to `DEST`.
